function [datout] = Globmean(datin)
%Globmean Takes global mean of input data (datin) and outputs as the
%structure datout

%MODEL INPUT
M_L_In = [nanmean(datin.Model_Input.M_L_In) nanstd(datin.Model_Input.M_L_In)];
BPang_IN = [nanmean(datin.Model_Input.BPang_IN) nanstd(datin.Model_Input.BPang_IN)];
M_L_Phase = [nanmean(datin.Model_Input.M_L_Phase) nanstd(datin.Model_Input.M_L_Phase)];
BPang_Phase = [nanmean(datin.Model_Input.BPang_Phase) nanstd(datin.Model_Input.BPang_Phase)];
M_L_In_wav = [nanmean(datin.Model_Input.M_L_In_wav); nanstd(datin.Model_Input.M_L_In_wav)];
BPang_IN_wav = [nanmean(datin.Model_Input.BPang_IN_wav); nanstd(datin.Model_Input.BPang_IN_wav)];

%MASS DISPLACEMENT
Ax_Rel = [nanmean(datin.Mass_Displacement.Ax_Rel) nanstd(datin.Mass_Displacement.Ax_Rel)];
Ax_Glob = [nanmean(datin.Mass_Displacement.Ax_Glob) nanstd(datin.Mass_Displacement.Ax_Glob)];
Pendulum_Phase = [nanmean(datin.Mass_Displacement.Pendulum_Phase) nanstd(datin.Mass_Displacement.Pendulum_Phase)];
Ax_Rel_Phase = [nanmean(datin.Mass_Displacement.Ax_Rel_Phase) nanstd(datin.Mass_Displacement.Ax_Rel_Phase)];
Ax_Glob_Phase = [nanmean(datin.Mass_Displacement.Ax_Glob_Phase) nanstd(datin.Mass_Displacement.Ax_Glob_Phase)];
Amp_Ratio = [nanmean(datin.Mass_Displacement.Amp_Ratio) nanstd(datin.Mass_Displacement.Amp_Ratio)];
Ax_Rel_wav = [nanmean(datin.Mass_Displacement.Ax_Rel_wav); nanstd(datin.Mass_Displacement.Ax_Rel_wav)];
Ax_Glob_wav = [nanmean(datin.Mass_Displacement.Ax_Glob_wav); nanstd(datin.Mass_Displacement.Ax_Glob_wav)];

%DEVICE FORCE-MOMENT
Fx_peak = [nanmean(datin.Device_Force_Moment.Fx_peak) nanstd(datin.Device_Force_Moment.Fx_peak)];
Fz_peak = [nanmean(datin.Device_Force_Moment.Fz_peak) nanstd(datin.Device_Force_Moment.Fz_peak)];
My_peak = [nanmean(datin.Device_Force_Moment.My_peak) nanstd(datin.Device_Force_Moment.My_peak)];
Fx_mean_wav = [nanmean(datin.Device_Force_Moment.Fx_mean_wav); nanstd(datin.Device_Force_Moment.Fx_mean_wav)];
Fz_mean_wav = [nanmean(datin.Device_Force_Moment.Fz_mean_wav); nanstd(datin.Device_Force_Moment.Fz_mean_wav)];
My_mean_wav = [nanmean(datin.Device_Force_Moment.My_mean_wav); nanstd(datin.Device_Force_Moment.My_mean_wav)];

%ELECTRICAL POWER
P_elec = [nanmean(datin.P_elec.P_elec) nanstd(datin.P_elec.P_elec)];
P_wav = [nanmean(datin.P_elec.P_wav); nanstd(datin.P_elec.P_wav)];
V_wav = [nanmean(datin.P_elec.V_wav); nanstd(datin.P_elec.V_wav)];
I_wav = [nanmean(datin.P_elec.I_wav); nanstd(datin.P_elec.I_wav)];

%JOINT ANGLES
AA_FlEx = [nanmean(datin.Joint_Ang.AA_FlEx); nanstd(datin.Joint_Ang.AA_FlEx)];
AA_InEv = [nanmean(datin.Joint_Ang.AA_InEv); nanstd(datin.Joint_Ang.AA_InEv)];
KA_FlEx = [nanmean(datin.Joint_Ang.KA_FlEx); nanstd(datin.Joint_Ang.KA_FlEx)];
KA_AbAd = [nanmean(datin.Joint_Ang.KA_AbAd); nanstd(datin.Joint_Ang.KA_AbAd)];
HA_FlEx = [nanmean(datin.Joint_Ang.HA_FlEx); nanstd(datin.Joint_Ang.HA_FlEx)];
HA_AbAd = [nanmean(datin.Joint_Ang.HA_AbAd); nanstd(datin.Joint_Ang.HA_FlEx)];

%JOINT MOMENTS - Normalized to Body Mass
AM_wav = [nanmean(datin.Joint_Mom.AM_wav(1:3:end,:)); nanmean(datin.Joint_Mom.AM_wav(2:3:end,:)); nanmean(datin.Joint_Mom.AM_wav(3:3:end,:))];
KM_wav = [nanmean(datin.Joint_Mom.KM_wav(1:3:end,:)); nanmean(datin.Joint_Mom.KM_wav(2:3:end,:)); nanmean(datin.Joint_Mom.KM_wav(3:3:end,:))];
HM_wav = [nanmean(datin.Joint_Mom.HM_wav(1:3:end,:)); nanmean(datin.Joint_Mom.HM_wav(2:3:end,:)); nanmean(datin.Joint_Mom.HM_wav(3:3:end,:))];
Amx_pkp = [nanmean(datin.Joint_Mom.Amx_pkp) nanstd(datin.Joint_Mom.Amx_pkp)];
Amx_pkn = [nanmean(datin.Joint_Mom.Amx_pkn) nanstd(datin.Joint_Mom.Amx_pkn)];
Amy_pkp1 = [nanmean(datin.Joint_Mom.Amy_pkp1) nanstd(datin.Joint_Mom.Amy_pkp1)];
Amy_pkp2 = [nanmean(datin.Joint_Mom.Amy_pkp2) nanstd(datin.Joint_Mom.Amy_pkp2)];
Kmx_pkp = [nanmean(datin.Joint_Mom.Kmx_pkp) nanstd(datin.Joint_Mom.Kmx_pkp)];
Kmx_pkn = [nanmean(datin.Joint_Mom.Kmx_pkn) nanstd(datin.Joint_Mom.Kmx_pkn)];
Kmy_pkp1 = [nanmean(datin.Joint_Mom.Kmy_pkp1) nanstd(datin.Joint_Mom.Kmy_pkp1)];
Kmy_pkp2 = [nanmean(datin.Joint_Mom.Kmy_pkp2) nanstd(datin.Joint_Mom.Kmy_pkp2)];
Hmx_pkp = [nanmean(datin.Joint_Mom.Hmx_pkp) nanstd(datin.Joint_Mom.Hmx_pkp)];
Hmx_pkn = [nanmean(datin.Joint_Mom.Hmx_pkn) nanstd(datin.Joint_Mom.Hmx_pkn)];
Hmy_pkp1 = [nanmean(datin.Joint_Mom.Hmy_pkp1) nanstd(datin.Joint_Mom.Hmy_pkp1)];
Hmy_pkp2 = [nanmean(datin.Joint_Mom.Hmy_pkp2) nanstd(datin.Joint_Mom.Hmy_pkp2)];

%JOINT POWER - Normalized to Body Mass
AP_wav = [nanmean(datin.Joint_Pow.AP_wav); nanstd(datin.Joint_Pow.AP_wav)];
KP_wav = [nanmean(datin.Joint_Pow.KP_wav); nanstd(datin.Joint_Pow.KP_wav)];
HP_wav = [nanmean(datin.Joint_Pow.HP_wav); nanstd(datin.Joint_Pow.HP_wav)]; 
Ap_pkp = [nanmean(datin.Joint_Pow.Ap_pkp) nanstd(datin.Joint_Pow.Ap_pkp)];
Ap_pkn = [nanmean(datin.Joint_Pow.Ap_pkn) nanstd(datin.Joint_Pow.Ap_pkn)];
Kp_pkn = [nanmean(datin.Joint_Pow.Kp_pkn) nanstd(datin.Joint_Pow.Kp_pkn)];
Hp_pkp1 = [nanmean(datin.Joint_Pow.Hp_pkp1) nanstd(datin.Joint_Pow.Hp_pkp1)];
Hp_pkp2 = [nanmean(datin.Joint_Pow.Hp_pkp2) nanstd(datin.Joint_Pow.Hp_pkp2)];
Hp_pkn = [nanmean(datin.Joint_Pow.Hp_pkn) nanstd(datin.Joint_Pow.Hp_pkn)];

%JOINT WORK - Normalized to Body Mass
Awp = [nanmean(datin.Joint_Work.Awp) nanstd(datin.Joint_Work.Awp)];
Awn = [nanmean(datin.Joint_Work.Awn) nanstd(datin.Joint_Work.Awn)];
Kwp = [nanmean(datin.Joint_Work.Kwp) nanstd(datin.Joint_Work.Kwp)];
Kwn = [nanmean(datin.Joint_Work.Kwn) nanstd(datin.Joint_Work.Kwn)];
Hwp = [nanmean(datin.Joint_Work.Hwp) nanstd(datin.Joint_Work.Hwp)];
Hwn = [nanmean(datin.Joint_Work.Hwn) nanstd(datin.Joint_Work.Hwn)];

%SPATIAL TEMPORAL PARAMETERS - Normalized to Leg Length (except
%frequency)
Stride_frequency = [nanmean(datin.Spat_Temp_Parameters.Stride_frequency) nanstd(datin.Spat_Temp_Parameters.Stride_frequency)];
Stride_width = [nanmean(datin.Spat_Temp_Parameters.Stride_width) nanstd(datin.Spat_Temp_Parameters.Stride_width)];
Stride_length = [nanmean(datin.Spat_Temp_Parameters.Stride_length) nanstd(datin.Spat_Temp_Parameters.Stride_length)];

%GRF - Normalized to Body Mass
GRF_pos_impulse = [nanmean(datin.GRF.GRF_pos_impulse(1:3:end)) nanstd(datin.GRF.GRF_pos_impulse(1:3:end));
    nanmean(datin.GRF.GRF_pos_impulse(2:3:end)) nanstd(datin.GRF.GRF_pos_impulse(2:3:end));
    nanmean(datin.GRF.GRF_pos_impulse(3:3:end)) nanstd(datin.GRF.GRF_pos_impulse(3:3:end))];
GRF_neg_impulse = [nanmean(datin.GRF.GRF_neg_impulse(1:3:end)) nanstd(datin.GRF.GRF_neg_impulse(1:3:end));
    nanmean(datin.GRF.GRF_neg_impulse(2:3:end)) nanstd(datin.GRF.GRF_neg_impulse(2:3:end));
    nanmean(datin.GRF.GRF_neg_impulse(3:3:end)) nanstd(datin.GRF.GRF_neg_impulse(3:3:end))];
GRF_mean_waveform = [nanmean(datin.GRF.GRF_mean_waveform(1:3:end,:));
    nanmean(datin.GRF.GRF_mean_waveform(2:3:end,:));
    nanmean(datin.GRF.GRF_mean_waveform(3:3:end,:))];

%MOS - Normalized to Leg Length
MoS_min = [nanmean(datin.MoS.MoS_min) nanstd(datin.MoS.MoS_min)];
MoS_std = [nanmean(datin.MoS.MoS_std) nanstd(datin.MoS.MoS_std)];

%COM M-L POSITION - Normalized to Leg Length
COM_excursion_ML = [nanmean(datin.COM_pos_ML.COM_excursion_ML) nanstd(datin.COM_pos_ML.COM_excursion_ML)];
COM_Excursion_ML_StDev = [nanmean(datin.COM_pos_ML.COM_Excursion_ML_StDev) nanstd(datin.COM_pos_ML.COM_Excursion_ML_StDev)];

%MODEL_pre_Adj
Amp_Ratio_mod = [nanmean(datin.Model.Amp_Ratio_mod) nanstd(datin.Model.Amp_Ratio_mod)];
P_elec_mod = [nanmean(datin.Model.P_elec_mod) nanstd(datin.Model.P_elec_mod)];
Experimental_Fr = [nanmean(datin.Model.Experimental_Fr) nanstd(datin.Model.Experimental_Fr)];
Ax_Rel_Phase_mod = [nanmean(datin.Model.Ax_Rel_Phase_mod) nanstd(datin.Model.Ax_Rel_Phase_mod)];
Fx_mod = [nanmean(datin.Model.Fx_mod) nanstd(datin.Model.Fx_mod)];
My_mod = [nanmean(datin.Model.My_mod) nanstd(datin.Model.My_mod)];

%MODEL
Amp_Ratio_mod_adj = [nanmean(datin.Model_adj.Amp_Ratio_mod_adj) nanstd(datin.Model_adj.Amp_Ratio_mod_adj)];
P_elec_mod_adj = [nanmean(datin.Model_adj.P_elec_mod_adj) nanstd(datin.Model_adj.P_elec_mod_adj)];
Experimental_Fr_adj = [nanmean(datin.Model_adj.Experimental_Fr_adj) nanstd(datin.Model_adj.Experimental_Fr_adj)];
Ax_Rel_Phase_mod_adj = [nanmean(datin.Model_adj.Ax_Rel_Phase_mod_adj) nanstd(datin.Model_adj.Ax_Rel_Phase_mod_adj)];
Fx_mod_adj = [nanmean(datin.Model_adj.Fx_mod_adj) nanstd(datin.Model_adj.Fx_mod_adj)];
My_mod_adj = [nanmean(datin.Model_adj.My_mod_adj) nanstd(datin.Model_adj.My_mod_adj)];

%METABOLIC - Normalized to Body Mass
Meta = [nanmean(datin.Meta.Meta) nanstd(datin.Meta.Meta)];

Extra = [nanmean(NaN(11,2)) nanstd(NaN(11,2))];

%GAIT VARIABILITY
SW_var = [nanmean(datin.VarExt.SW_var) nanstd(datin.VarExt.SW_var)];
SL_var = [nanmean(datin.VarExt.SL_var) nanstd(datin.VarExt.SL_var)];



%% Creating Structures

Model_Input = struct('M_L_In', M_L_In, 'BPang_IN', BPang_IN,'M_L_Phase',...
    M_L_Phase, 'BPang_Phase',BPang_Phase,'M_L_In_wav',M_L_In_wav,...
    'BPang_IN_wav',BPang_IN_wav);

Mass_Displacement = struct('Ax_Rel',Ax_Rel,'Ax_Glob',Ax_Glob,'Pendulum_Phase',Pendulum_Phase,...
    'Ax_Rel_Phase',Ax_Rel_Phase,'Ax_Glob_Phase',Ax_Glob_Phase,'Amp_Ratio',Amp_Ratio,...
    'Ax_Rel_wav',Ax_Rel_wav,'Ax_Glob_wav',Ax_Glob_wav);

Device_Force_Moment = struct('Fx_peak',Fx_peak,'Fz_peak',Fz_peak,'My_peak',My_peak,...
    'Fx_mean_wav',Fx_mean_wav,'Fz_mean_wav',Fz_mean_wav,'My_mean_wav',My_mean_wav);

P_elec = struct('P_elec',P_elec,'P_wav',P_wav,'V_wav',V_wav,'I_wav',I_wav);

Joint_Ang = struct('AA_FlEx',AA_FlEx,'AA_InEv',AA_InEv,'KA_FlEx',KA_FlEx,...
    'KA_AbAd',KA_AbAd,'HA_FlEx',HA_FlEx,'HA_AbAd',HA_AbAd);

Joint_Mom = struct('AM_wav',AM_wav,'KM_wav',KM_wav,'HM_wav',HM_wav,'Amx_pkp',Amx_pkp,...
    'Amx_pkn',Amx_pkn,'Amy_pkp1',Amy_pkp1,'Amy_pkp2',Amy_pkp2,'Kmx_pkp',Kmx_pkp,...
    'Kmx_pkn',Kmx_pkn,'Kmy_pkp1',Kmy_pkp1,'Kmy_pkp2',Kmy_pkp2,'Hmx_pkp',Hmx_pkp,...
    'Hmx_pkn',Hmx_pkn,'Hmy_pkp1',Hmy_pkp1,'Hmy_pkp2',Hmy_pkp2);

Joint_Pow = struct('AP_wav',AP_wav,'KP_wav',KP_wav,'HP_wav',HP_wav,'Ap_pkp',Ap_pkp,...
    'Ap_pkn',Ap_pkn,'Kp_pkn',Kp_pkn,'Hp_pkp1',Hp_pkp1,'Hp_pkp2',Hp_pkp2,...
    'Hp_pkn',Hp_pkn);

Joint_Work = struct('Awp',Awp,'Awn',Awn,'Kwp',Kwp,'Kwn',Kwn,'Hwp',Hwp,'Hwn',Hwn);

Spat_Temp_Parameters = struct('Stride_frequency',Stride_frequency,'Stride_width',...
    Stride_width, 'Stride_length',Stride_length);

GRF = struct('GRF_pos_impulse',GRF_pos_impulse,'GRF_neg_impulse',GRF_neg_impulse,...
    'GRF_mean_waveform',GRF_mean_waveform);

MoS = struct('MoS_min',MoS_min,'MoS_std',MoS_std);

COM_pos_ML = struct('COM_excursion_ML',COM_excursion_ML,'COM_Excursion_ML_StDev',COM_Excursion_ML_StDev);

Model = struct('Amp_Ratio_mod',Amp_Ratio_mod,'P_elec_mod',P_elec_mod,'Experimental_Fr',Experimental_Fr,...
    'Ax_Rel_Phase_mod',Ax_Rel_Phase_mod,'Fx_mod',Fx_mod,'My_mod',My_mod);

Model_adj = struct('Amp_Ratio_mod_adj',Amp_Ratio_mod_adj,'P_elec_mod_adj',P_elec_mod_adj,'Experimental_Fr_adj',Experimental_Fr_adj,...
    'Ax_Rel_Phase_mod_adj',Ax_Rel_Phase_mod_adj,'Fx_mod_adj',Fx_mod_adj,'My_mod_adj',My_mod_adj);

Meta = struct('Meta',Meta);

VarExt = struct('Extra',Extra,'SW_var',SW_var,'SL_var',SL_var);

%% Output
datout = struct('Model_Input',Model_Input,'Mass_Displacement',Mass_Displacement,...
    'Device_Force_Moment',Device_Force_Moment,'P_elec',P_elec,'Joint_Ang',Joint_Ang,...
    'Joint_Mom',Joint_Mom,'Joint_Pow',Joint_Pow,'Joint_Work',Joint_Work,...
    'Spat_Temp_Parameters',Spat_Temp_Parameters,'GRF',GRF,'MoS',MoS,...
    'COM_pos_ML',COM_pos_ML,'Model',Model,'Model_adj',Model_adj,'Meta',Meta,'VarExt',VarExt);

end

