function [datout] = SubAmal(datin,metain,datpre,ignore,sub_info)
%SubAmal Adds condition to pre-existing data set
%   Takes subject's data (datin, metain) for a particular trial and adds it to
%   pre-existing amalgamation of global data (datpre). Ignores (ignore)
%   requested trials and replaces with NaN values. Normalizes using subject
%   information (sub_info)

ignore(ignore == 0) = NaN;

if isempty(datpre) == 1
    %Treat as first input submission
    %MODEL INPUT
    M_L_In = datin.Model_Input.M_L_In*ignore(1);
    BPang_IN = datin.Model_Input.BPang_IN*ignore(2);
    M_L_Phase = datin.Model_Input.M_L_Phase*ignore(3);
    BPang_Phase = datin.Model_Input.BPang_Phase*ignore(4);
    M_L_In_wav = datin.Model_Input.M_L_In_wav.*ignore(5);
    BPang_IN_wav = datin.Model_Input.BPang_IN_wav.*ignore(6);
    
    %MASS DISPLACEMENT
    Ax_Rel = datin.Mass_Displacement.Ax_Rel*ignore(7);
    Ax_Glob = datin.Mass_Displacement.Ax_Glob*ignore(8);
    Pendulum_Phase = datin.Mass_Displacement.Pendulum_Phase*ignore(9);
    Ax_Rel_Phase = datin.Mass_Displacement.Ax_Rel_Phase*ignore(10);
    Ax_Glob_Phase = datin.Mass_Displacement.Ax_Glob_Phase*ignore(11);
    Amp_Ratio = datin.Mass_Displacement.Amp_Ratio*ignore(12);
    Ax_Rel_wav = datin.Mass_Displacement.Ax_Rel_wav.*ignore(13);
    Ax_Glob_wav = datin.Mass_Displacement.Ax_Glob_wav.*ignore(14);
    
    %DEVICE FORCE-MOMENT
    Fx_peak = datin.Device_Force_Moment.Fx_peak*ignore(15);
    Fz_peak = datin.Device_Force_Moment.Fz_peak*ignore(16);
    My_peak = datin.Device_Force_Moment.My_peak*ignore(17);
    Fx_mean_wav = datin.Device_Force_Moment.Fx_mean_wav.*ignore(18);
    Fz_mean_wav = datin.Device_Force_Moment.Fz_mean_wav.*ignore(19);
    My_mean_wav = datin.Device_Force_Moment.My_mean_wav.*ignore(20);
    
    %ELECTRICAL POWER
    P_elec = datin.P_elec.P_elec*ignore(21);
    P_wav = datin.P_elec.P_wav.*ignore(22);
    V_wav = datin.P_elec.V_wav.*ignore(23);
    I_wav = datin.P_elec.I_wav.*ignore(24);
    
    %JOINT ANGLES
    AA_FlEx = datin.Joint_Ang.AA_FlEx.*ignore(25);
    AA_InEv = datin.Joint_Ang.AA_InEv.*ignore(26);
    KA_FlEx = datin.Joint_Ang.KA_FlEx.*ignore(27);
    KA_AbAd = datin.Joint_Ang.KA_AbAd.*ignore(28);
    HA_FlEx = datin.Joint_Ang.HA_FlEx.*ignore(29);
    HA_AbAd = datin.Joint_Ang.HA_AbAd.*ignore(30);
    
    %JOINT MOMENTS - Normalized to Body Mass
    AM_wav = datin.Joint_Mom.AM_wav.*ignore(31)./sub_info(4);
    KM_wav = datin.Joint_Mom.KM_wav.*ignore(32)./sub_info(4);
    HM_wav = datin.Joint_Mom.HM_wav.*ignore(33)./sub_info(4);
    Amx_pkp = datin.Joint_Mom.Amx_pkp.*ignore(34)./sub_info(4);
    Amx_pkn = datin.Joint_Mom.Amx_pkn.*ignore(35)./sub_info(4);
    Amy_pkp1 = datin.Joint_Mom.Amy_pkp1.*ignore(36)./sub_info(4);
    Amy_pkp2 = datin.Joint_Mom.Amy_pkp2.*ignore(37)./sub_info(4);
    Kmx_pkp = datin.Joint_Mom.Kmx_pkp.*ignore(38)./sub_info(4);
    Kmx_pkn = datin.Joint_Mom.Kmx_pkn.*ignore(39)./sub_info(4);
    Kmy_pkp1 = datin.Joint_Mom.Kmy_pkp1.*ignore(40)./sub_info(4);
    Kmy_pkp2 = datin.Joint_Mom.Kmy_pkp2.*ignore(41)./sub_info(4);
    Hmx_pkp = datin.Joint_Mom.Hmx_pkp.*ignore(42)./sub_info(4);
    Hmx_pkn = datin.Joint_Mom.Hmx_pkn.*ignore(43)./sub_info(4);
    Hmy_pkp1 = datin.Joint_Mom.Hmy_pkp1.*ignore(44)./sub_info(4);
    Hmy_pkp2 = datin.Joint_Mom.Hmy_pkp2.*ignore(45)./sub_info(4);
    
    %JOINT POWER - Normalized to Body Mass
    AP_wav = datin.Joint_Pow.AP_wav.*ignore(46)./sub_info(4);
    KP_wav = datin.Joint_Pow.KP_wav.*ignore(47)./sub_info(4);
    HP_wav = datin.Joint_Pow.HP_wav.*ignore(48)./sub_info(4);
    Ap_pkp = datin.Joint_Pow.Ap_pkp.*ignore(49)./sub_info(4);
    Ap_pkn = datin.Joint_Pow.Ap_pkn.*ignore(50)./sub_info(4);
    Kp_pkn = datin.Joint_Pow.Kp_pkn.*ignore(51)./sub_info(4);
    Hp_pkp1 = datin.Joint_Pow.Hp_pkp1.*ignore(52)./sub_info(4);
    Hp_pkp2 = datin.Joint_Pow.Hp_pkp2.*ignore(53)./sub_info(4);
    Hp_pkn = datin.Joint_Pow.Hp_pkn.*ignore(54)./sub_info(4);
    
    %JOINT WORK - Normalized to Body Mass
    Awp = datin.Joint_Work.Awp.*ignore(55)./sub_info(4);
    Awn = datin.Joint_Work.Awn.*ignore(56)./sub_info(4);
    Kwp = datin.Joint_Work.Kwp.*ignore(57)./sub_info(4);
    Kwn = datin.Joint_Work.Kwn.*ignore(58)./sub_info(4);
    Hwp = datin.Joint_Work.Hwp.*ignore(59)./sub_info(4);
    Hwn = datin.Joint_Work.Hwn.*ignore(60)./sub_info(4);
    
    %SPATIAL TEMPORAL PARAMETERS - Normalized to Leg Length (except
    %frequency)
    Stride_frequency = datin.Spat_Temp_Parameters.Stride_frequency.*ignore(61);
    Stride_width = datin.Spat_Temp_Parameters.Stride_width.*ignore(62)./10./sub_info(5);
    Stride_length = datin.Spat_Temp_Parameters.Stride_length.*ignore(63)./10./sub_info(5);
    
    %GRF - Normalized to Body Mass
    GRF_pos_impulse = datin.GRF.GRF_pos_impulse.*ignore(64)./sub_info(4);
    GRF_neg_impulse = datin.GRF.GRF_neg_impulse.*ignore(65)./sub_info(4);
    GRF_mean_waveform = datin.GRF.GRF_mean_waveform.*ignore(66)./sub_info(4);
    
    %MOS - Normalized to Leg Length
    MoS_min = datin.MoS.MoS_min.*ignore(67)./sub_info(5);
    MoS_std = datin.MoS.MoS_std.*ignore(68)./sub_info(5);
    
    %COM M-L POSITION - Normalized to Leg Length
    COM_excursion_ML = datin.COM_pos_ML.COM_excursion_ML.*ignore(69)./sub_info(5);
    COM_Excursion_ML_StDev = datin.COM_pos_ML.COM_Excursion_ML_StDev.*ignore(70)./sub_info(5);

    %MODEL
    Amp_Ratio_mod = datin.Model.Amp_Ratio_mod.*ignore(71);
    P_elec_mod = datin.Model.P_elec_mod.*ignore(72);
    Experimental_Fr = datin.Model.Experimental_Fr.*ignore(73);
    Ax_Rel_Phase_mod = datin.Model.Ax_Rel_Phase_mod.*ignore(74);
    Fx_mod = datin.Model.Fx_mod.*ignore(75);
    My_mod = datin.Model.My_mod.*ignore(76);
    
    %ADJUSTED MODEL
    Amp_Ratio_mod_adj = datin.Model_adj.Amp_Ratio_mod.*ignore(77);
    P_elec_mod_adj = datin.Model_adj.P_elec_mod.*ignore(78);
    Experimental_Fr_adj = datin.Model_adj.Experimental_Fr.*ignore(79);
    Ax_Rel_Phase_mod_adj = datin.Model_adj.Ax_Rel_Phase_mod.*ignore(80);
    Fx_mod_adj = datin.Model_adj.Fx_mod.*ignore(81);
    My_mod_adj = datin.Model_adj.My_mod.*ignore(82);
    
    %METABOLIC - Normalized to Body Mass
    Meta = metain.*ignore(83)./sub_info(4);
    
    Extra = NaN(1,2).*ignore(84);
    
    %GAIT VARIABILITY
    SW_var = datin.VarExt.SW_var.*ignore(85)./10./sub_info(5);
    SL_var = datin.VarExt.SL_var.*ignore(86)./10./sub_info(5);
    
else
    %Treat as addition to datpre
    %MODEL INPUT
    M_L_In = [datpre.Model_Input.M_L_In; datin.Model_Input.M_L_In*ignore(1)];
    BPang_IN = [datpre.Model_Input.BPang_IN; datin.Model_Input.BPang_IN*ignore(2)];
    M_L_Phase = [datpre.Model_Input.M_L_Phase; datin.Model_Input.M_L_Phase*ignore(3)];
    BPang_Phase = [datpre.Model_Input.BPang_Phase; datin.Model_Input.BPang_Phase*ignore(4)];
    M_L_In_wav = [datpre.Model_Input.M_L_In_wav; datin.Model_Input.M_L_In_wav.*ignore(5)];
    BPang_IN_wav = [datpre.Model_Input.BPang_IN_wav; datin.Model_Input.BPang_IN_wav.*ignore(6)];
    
    %MASS DISPLACEMENT
    Ax_Rel = [datpre.Mass_Displacement.Ax_Rel; datin.Mass_Displacement.Ax_Rel*ignore(7)];
    Ax_Glob = [datpre.Mass_Displacement.Ax_Glob; datin.Mass_Displacement.Ax_Glob*ignore(8)];
    Pendulum_Phase = [datpre.Mass_Displacement.Pendulum_Phase; datin.Mass_Displacement.Pendulum_Phase*ignore(9)];
    Ax_Rel_Phase = [datpre.Mass_Displacement.Ax_Rel_Phase; datin.Mass_Displacement.Ax_Rel_Phase*ignore(10)];
    Ax_Glob_Phase = [datpre.Mass_Displacement.Ax_Glob_Phase; datin.Mass_Displacement.Ax_Glob_Phase*ignore(11)];
    Amp_Ratio = [datpre.Mass_Displacement.Amp_Ratio; datin.Mass_Displacement.Amp_Ratio*ignore(12)];
    Ax_Rel_wav = [datpre.Mass_Displacement.Ax_Rel_wav; datin.Mass_Displacement.Ax_Rel_wav.*ignore(13)];
    Ax_Glob_wav = [datpre.Mass_Displacement.Ax_Glob_wav; datin.Mass_Displacement.Ax_Glob_wav.*ignore(14)];
    
    %DEVICE FORCE-MOMENT
    Fx_peak = [datpre.Device_Force_Moment.Fx_peak; datin.Device_Force_Moment.Fx_peak*ignore(15)];
    Fz_peak = [datpre.Device_Force_Moment.Fz_peak; datin.Device_Force_Moment.Fz_peak*ignore(16)];
    My_peak = [datpre.Device_Force_Moment.My_peak; datin.Device_Force_Moment.My_peak*ignore(17)];
    Fx_mean_wav = [datpre.Device_Force_Moment.Fx_mean_wav; datin.Device_Force_Moment.Fx_mean_wav.*ignore(18)];
    Fz_mean_wav = [datpre.Device_Force_Moment.Fz_mean_wav; datin.Device_Force_Moment.Fz_mean_wav.*ignore(19)];
    My_mean_wav = [datpre.Device_Force_Moment.My_mean_wav; datin.Device_Force_Moment.My_mean_wav.*ignore(20)];
    
    %ELECTRICAL POWER
    P_elec = [datpre.P_elec.P_elec; datin.P_elec.P_elec*ignore(21)];
    P_wav = [datpre.P_elec.P_wav; datin.P_elec.P_wav.*ignore(22)];
    V_wav = [datpre.P_elec.V_wav; datin.P_elec.V_wav.*ignore(23)];
    I_wav = [datpre.P_elec.I_wav; datin.P_elec.I_wav.*ignore(24)];
    
    %JOINT ANGLES
    AA_FlEx = [datpre.Joint_Ang.AA_FlEx; datin.Joint_Ang.AA_FlEx.*ignore(25)];
    AA_InEv = [datpre.Joint_Ang.AA_InEv; datin.Joint_Ang.AA_InEv.*ignore(26)];
    KA_FlEx = [datpre.Joint_Ang.KA_FlEx; datin.Joint_Ang.KA_FlEx.*ignore(27)];
    KA_AbAd = [datpre.Joint_Ang.KA_AbAd; datin.Joint_Ang.KA_AbAd.*ignore(28)];
    HA_FlEx = [datpre.Joint_Ang.HA_FlEx; datin.Joint_Ang.HA_FlEx.*ignore(29)];
    HA_AbAd = [datpre.Joint_Ang.HA_AbAd; datin.Joint_Ang.HA_AbAd.*ignore(30)];
    
    %JOINT MOMENTS - Normalized to Body Mass
    AM_wav = [datpre.Joint_Mom.AM_wav; datin.Joint_Mom.AM_wav.*ignore(31)./sub_info(4)];
    KM_wav = [datpre.Joint_Mom.KM_wav; datin.Joint_Mom.KM_wav.*ignore(32)./sub_info(4)];
    HM_wav = [datpre.Joint_Mom.HM_wav; datin.Joint_Mom.HM_wav.*ignore(33)./sub_info(4)];
    Amx_pkp = [datpre.Joint_Mom.Amx_pkp; datin.Joint_Mom.Amx_pkp.*ignore(34)./sub_info(4)];
    Amx_pkn = [datpre.Joint_Mom.Amx_pkn; datin.Joint_Mom.Amx_pkn.*ignore(35)./sub_info(4)];
    Amy_pkp1 = [datpre.Joint_Mom.Amy_pkp1; datin.Joint_Mom.Amy_pkp1.*ignore(36)./sub_info(4)];
    Amy_pkp2 = [datpre.Joint_Mom.Amy_pkp2; datin.Joint_Mom.Amy_pkp2.*ignore(37)./sub_info(4)];
    Kmx_pkp = [datpre.Joint_Mom.Kmx_pkp; datin.Joint_Mom.Kmx_pkp.*ignore(38)./sub_info(4)];
    Kmx_pkn = [datpre.Joint_Mom.Kmx_pkn; datin.Joint_Mom.Kmx_pkn.*ignore(39)./sub_info(4)];
    Kmy_pkp1 = [datpre.Joint_Mom.Kmy_pkp1; datin.Joint_Mom.Kmy_pkp1.*ignore(40)./sub_info(4)];
    Kmy_pkp2 = [datpre.Joint_Mom.Kmy_pkp2; datin.Joint_Mom.Kmy_pkp2.*ignore(41)./sub_info(4)];
    Hmx_pkp = [datpre.Joint_Mom.Hmx_pkp; datin.Joint_Mom.Hmx_pkp.*ignore(42)./sub_info(4)];
    Hmx_pkn = [datpre.Joint_Mom.Hmx_pkn; datin.Joint_Mom.Hmx_pkn.*ignore(43)./sub_info(4)];
    Hmy_pkp1 = [datpre.Joint_Mom.Hmy_pkp1; datin.Joint_Mom.Hmy_pkp1.*ignore(44)./sub_info(4)];
    Hmy_pkp2 = [datpre.Joint_Mom.Hmy_pkp2; datin.Joint_Mom.Hmy_pkp2.*ignore(45)./sub_info(4)];

    %JOINT POWER - Normalized to Body Mass
    AP_wav = [datpre.Joint_Pow.AP_wav; datin.Joint_Pow.AP_wav.*ignore(46)./sub_info(4)];
    KP_wav = [datpre.Joint_Pow.KP_wav; datin.Joint_Pow.KP_wav.*ignore(47)./sub_info(4)];
    HP_wav = [datpre.Joint_Pow.HP_wav; datin.Joint_Pow.HP_wav.*ignore(48)./sub_info(4)];
    Ap_pkp = [datpre.Joint_Pow.Ap_pkp; datin.Joint_Pow.Ap_pkp.*ignore(49)./sub_info(4)];
    Ap_pkn = [datpre.Joint_Pow.Ap_pkn; datin.Joint_Pow.Ap_pkn.*ignore(50)./sub_info(4)];
    Kp_pkn = [datpre.Joint_Pow.Kp_pkn; datin.Joint_Pow.Kp_pkn.*ignore(51)./sub_info(4)];
    Hp_pkp1 = [datpre.Joint_Pow.Hp_pkp1; datin.Joint_Pow.Hp_pkp1.*ignore(52)./sub_info(4)];
    Hp_pkp2 = [datpre.Joint_Pow.Hp_pkp2; datin.Joint_Pow.Hp_pkp2.*ignore(53)./sub_info(4)];
    Hp_pkn = [datpre.Joint_Pow.Hp_pkn; datin.Joint_Pow.Hp_pkn.*ignore(54)./sub_info(4)];
    
    %JOINT WORK - Normalized to Body Mass
    Awp = [datpre.Joint_Work.Awp; datin.Joint_Work.Awp.*ignore(55)./sub_info(4)];
    Awn = [datpre.Joint_Work.Awn; datin.Joint_Work.Awn.*ignore(56)./sub_info(4)];
    Kwp = [datpre.Joint_Work.Kwp; datin.Joint_Work.Kwp.*ignore(57)./sub_info(4)];
    Kwn = [datpre.Joint_Work.Kwn; datin.Joint_Work.Kwn.*ignore(58)./sub_info(4)];
    Hwp = [datpre.Joint_Work.Hwp; datin.Joint_Work.Hwp.*ignore(59)./sub_info(4)];
    Hwn = [datpre.Joint_Work.Hwn; datin.Joint_Work.Hwn.*ignore(60)./sub_info(4)];
    
    %SPATIAL TEMPORAL PARAMETERS - Normalized to Leg Length (Except
    %frequency)
    Stride_frequency = [datpre.Spat_Temp_Parameters.Stride_frequency; datin.Spat_Temp_Parameters.Stride_frequency.*ignore(61)];
    Stride_width = [datpre.Spat_Temp_Parameters.Stride_width; datin.Spat_Temp_Parameters.Stride_width.*ignore(62)./10./sub_info(5)];
    Stride_length = [datpre.Spat_Temp_Parameters.Stride_length; datin.Spat_Temp_Parameters.Stride_length.*ignore(63)./10./sub_info(5)];
    
    %GRF - Normalized to Body Mass
    GRF_pos_impulse = [datpre.GRF.GRF_pos_impulse; datin.GRF.GRF_pos_impulse.*ignore(64)./sub_info(4)];
    GRF_neg_impulse = [datpre.GRF.GRF_neg_impulse; datin.GRF.GRF_neg_impulse.*ignore(65)./sub_info(4)];
    GRF_mean_waveform = [datpre.GRF.GRF_mean_waveform; datin.GRF.GRF_mean_waveform.*ignore(66)./sub_info(4)];
    
    %MOS - Normalized to Leg Length
    MoS_min = [datpre.MoS.MoS_min; datin.MoS.MoS_min.*ignore(67)./sub_info(5)];
    MoS_std = [datpre.MoS.MoS_std; datin.MoS.MoS_std.*ignore(68)./sub_info(5)];
    
    %COM M-L POSITION - Normalized to Leg Length
    COM_excursion_ML = [datpre.COM_pos_ML.COM_excursion_ML; datin.COM_pos_ML.COM_excursion_ML.*ignore(69)./sub_info(5)];
    COM_Excursion_ML_StDev = [datpre.COM_pos_ML.COM_Excursion_ML_StDev; datin.COM_pos_ML.COM_Excursion_ML_StDev.*ignore(70)./sub_info(5)];
    
    %MODEL
    Amp_Ratio_mod = [datpre.Model.Amp_Ratio_mod; datin.Model.Amp_Ratio_mod.*ignore(71)];
    P_elec_mod = [datpre.Model.P_elec_mod; datin.Model.P_elec_mod.*ignore(72)];
    Experimental_Fr = [datpre.Model.Experimental_Fr; datin.Model.Experimental_Fr.*ignore(73)];
    Ax_Rel_Phase_mod = [datpre.Model.Ax_Rel_Phase_mod; datin.Model.Ax_Rel_Phase_mod.*ignore(74)];
    Fx_mod = [datpre.Model.Fx_mod; datin.Model.Fx_mod.*ignore(75)];
    My_mod = [datpre.Model.My_mod; datin.Model.My_mod.*ignore(76)];
    
    %MODEL
    Amp_Ratio_mod_adj = [datpre.Model_adj.Amp_Ratio_mod_adj; datin.Model_adj.Amp_Ratio_mod.*ignore(77)];
    P_elec_mod_adj = [datpre.Model_adj.P_elec_mod_adj; datin.Model_adj.P_elec_mod.*ignore(78)];
    Experimental_Fr_adj = [datpre.Model_adj.Experimental_Fr_adj; datin.Model_adj.Experimental_Fr.*ignore(79)];
    Ax_Rel_Phase_mod_adj = [datpre.Model_adj.Ax_Rel_Phase_mod_adj; datin.Model_adj.Ax_Rel_Phase_mod.*ignore(80)];
    Fx_mod_adj = [datpre.Model_adj.Fx_mod_adj; datin.Model_adj.Fx_mod.*ignore(81)];
    My_mod_adj = [datpre.Model_adj.My_mod_adj; datin.Model_adj.My_mod.*ignore(82)];
    
    %METABOLIC - Normalized to Body Mass
    Meta = [datpre.Meta.Meta; metain.*ignore(83)./sub_info(4)];
    
    Extra = [datpre.VarExt.Extra; NaN(1,2)];
    
    %GAIT VARIABILITY
    SW_var = [datpre.VarExt.SW_var; datin.VarExt.SW_var.*ignore(85)./10./sub_info(5)];
    SL_var = [datpre.VarExt.SL_var; datin.VarExt.SL_var.*ignore(86)./10./sub_info(5)];
end

Model_Input = struct('M_L_In', M_L_In, 'BPang_IN', BPang_IN,'M_L_Phase',...
    M_L_Phase, 'BPang_Phase',BPang_Phase,'M_L_In_wav',M_L_In_wav,...
    'BPang_IN_wav',BPang_IN_wav);

Mass_Displacement = struct('Ax_Rel',Ax_Rel,'Ax_Glob',Ax_Glob,'Pendulum_Phase',Pendulum_Phase,...
    'Ax_Rel_Phase',Ax_Rel_Phase,'Ax_Glob_Phase',Ax_Glob_Phase,'Amp_Ratio',Amp_Ratio,...
    'Ax_Rel_wav',Ax_Rel_wav,'Ax_Glob_wav',Ax_Glob_wav);

Device_Force_Moment = struct('Fx_peak',Fx_peak,'Fz_peak',Fz_peak,'My_peak',My_peak,...
    'Fx_mean_wav',Fx_mean_wav,'Fz_mean_wav',Fz_mean_wav,'My_mean_wav',My_mean_wav);

P_elec = struct('P_elec',P_elec,'P_wav',P_wav,'V_wav',V_wav,'I_wav',I_wav);

Joint_Ang = struct('AA_FlEx',AA_FlEx,'AA_InEv',AA_InEv,'KA_FlEx',KA_FlEx,...
    'KA_AbAd',KA_AbAd,'HA_FlEx',HA_FlEx,'HA_AbAd',HA_AbAd);

Joint_Mom = struct('AM_wav',AM_wav,'KM_wav',KM_wav,'HM_wav',HM_wav,'Amx_pkp',Amx_pkp,...
    'Amx_pkn',Amx_pkn,'Amy_pkp1',Amy_pkp1,'Amy_pkp2',Amy_pkp2,'Kmx_pkp',Kmx_pkp,...
    'Kmx_pkn',Kmx_pkn,'Kmy_pkp1',Kmy_pkp1,'Kmy_pkp2',Kmy_pkp2,'Hmx_pkp',Hmx_pkp,...
    'Hmx_pkn',Hmx_pkn,'Hmy_pkp1',Hmy_pkp1,'Hmy_pkp2',Hmy_pkp2);

Joint_Pow = struct('AP_wav',AP_wav,'KP_wav',KP_wav,'HP_wav',HP_wav,'Ap_pkp',Ap_pkp,...
    'Ap_pkn',Ap_pkn,'Kp_pkn',Kp_pkn,'Hp_pkp1',Hp_pkp1,'Hp_pkp2',Hp_pkp2,...
    'Hp_pkn',Hp_pkn);

Joint_Work = struct('Awp',Awp,'Awn',Awn,'Kwp',Kwp,'Kwn',Kwn,'Hwp',Hwp,'Hwn',Hwn);

Spat_Temp_Parameters = struct('Stride_frequency',Stride_frequency,'Stride_width',...
    Stride_width, 'Stride_length',Stride_length);

GRF = struct('GRF_pos_impulse',GRF_pos_impulse,'GRF_neg_impulse',GRF_neg_impulse,...
    'GRF_mean_waveform',GRF_mean_waveform);

MoS = struct('MoS_min',MoS_min,'MoS_std',MoS_std);

COM_pos_ML = struct('COM_excursion_ML',COM_excursion_ML,'COM_Excursion_ML_StDev',COM_Excursion_ML_StDev);

Model = struct('Amp_Ratio_mod',Amp_Ratio_mod,'P_elec_mod',P_elec_mod,'Experimental_Fr',Experimental_Fr,...
    'Ax_Rel_Phase_mod',Ax_Rel_Phase_mod,'Fx_mod',Fx_mod,'My_mod',My_mod);

Model_adj = struct('Amp_Ratio_mod_adj',Amp_Ratio_mod_adj,'P_elec_mod_adj',P_elec_mod_adj,'Experimental_Fr_adj',Experimental_Fr_adj,...
    'Ax_Rel_Phase_mod_adj',Ax_Rel_Phase_mod_adj,'Fx_mod_adj',Fx_mod_adj,'My_mod_adj',My_mod_adj);

Meta = struct('Meta',Meta);

VarExt = struct('Extra',Extra,'SW_var',SW_var,'SL_var',SL_var);

datout = struct('Model_Input',Model_Input,'Mass_Displacement',Mass_Displacement,...
    'Device_Force_Moment',Device_Force_Moment,'P_elec',P_elec,'Joint_Ang',Joint_Ang,...
    'Joint_Mom',Joint_Mom,'Joint_Pow',Joint_Pow,'Joint_Work',Joint_Work,...
    'Spat_Temp_Parameters',Spat_Temp_Parameters,'GRF',GRF,'MoS',MoS,...
    'COM_pos_ML',COM_pos_ML,'Model',Model,'Model_adj',Model_adj,'Meta',Meta,'VarExt',VarExt);

end

